@@ -1,7 +1,7 @@
 #
 # This file is part of App-SpreadRevolutionaryDate
 #
-# This software is Copyright (c) 2019 by Gérald Sédrati-Dinet.
+# This software is Copyright (c) 2019-2022 by Gérald Sédrati.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate;
-$App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate::VERSION = '0.31';
+$App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate::VERSION = '0.32';
 # ABSTRACT: MsgMaker class for L<App::SpreadRevolutionaryDate> to build message with revolutionary date
 
 use Moose;
@@ -101,7 +101,7 @@ App::SpreadRevolutionaryDate::MsgMaker::RevolutionaryDate - MsgMaker class for L
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 METHODS
 
@@ -153,11 +153,11 @@ Computes revolutionary date. Takes no argument. Returns message as string, ready
 
 =head1 AUTHOR
 
-Gérald Sédrati-Dinet <gibus@cpan.org>
+Gérald Sédrati <gibus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Gérald Sédrati-Dinet.
+This software is Copyright (c) 2019-2022 by Gérald Sédrati.
 
 This is free software, licensed under:
 
